==> 1.0.89.tar.gz: lib/src/firebase_tratamientos_programados_repository.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:firebase_repository/firebase_repository.dart';
import 'package:firebase_repository/src/models/tratamiento_programado.dart';
import 'package:firebase_repository/src/tratamiento_programado_repository.dart';
import 'package:flutter/cupertino.dart';

class FirebaseTratamientosProgramadosRepository
    implements TratamientoProgramadoRepository {
  CollectionReference tratamientosProgramadosCollection;
  String empresaId;

  FirebaseTratamientosProgramadosRepository({@required String empresaId}) {
    this.tratamientosProgramadosCollection = Firestore.instance
        .collection('empresas')
        .document(empresaId)
        .collection('tratamientos_programados');
  }

  @override
  Future<void> addNewTratamientoProgramado(
      TratamientoProgramado tratamientoProgramado) {
    return tratamientosProgramadosCollection
        .add(tratamientoProgramado.toEntity().toDocument());
  }

  @override
  Future<void> deleteTratamientoProgramado(
      TratamientoProgramado tratamientoProgramado) {
    return tratamientosProgramadosCollection
        .document(tratamientoProgramado.uuid)
        .delete();
  }

  @override
  Stream<List<TratamientoProgramado>> tratamientosProgramados() {
    return tratamientosProgramadosCollection.where("pendiente", isEqualTo: true)
        .snapshots().map((snapshot) {
          print(snapshot);
          return snapshot.documents.map((doc) => TratamientoProgramado.fromEntity(TratamientoProgramadoEntity.fromSnapshot(doc))).toList();
    });
  }

  @override
  Future<void> updateTratamientoProgramado(
      TratamientoProgramado tratamientoProgramado) {
    return tratamientosProgramadosCollection.document(tratamientoProgramado.uuid).updateData(tratamientoProgramado.toEntity().toDocument());
  }
}

==> 1.0.878.tar.gz: lib/src/firebase_tratamientos_programados_repository.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:firebase_repository/firebase_repository.dart';
import 'package:firebase_repository/src/models/tratamiento_programado.dart';
import 'package:firebase_repository/src/tratamiento_programado_repository.dart';
import 'package:flutter/cupertino.dart';

class FirebaseTratamientosProgramadosRepository
    implements TratamientoProgramadoRepository {
  CollectionReference tratamientosProgramadosCollection;
  String empresaId;

  FirebaseTratamientosProgramadosRepository({@required String empresaId}) {
    this.tratamientosProgramadosCollection = Firestore.instance
        .collection('empresas')
        .document(empresaId)
        .collection('tratamientos_programados').where('pendiente', isEqualTo: true);
  }

  @override
  Future<void> addNewTratamientoProgramado(
      TratamientoProgramado tratamientoProgramado) {
    return tratamientosProgramadosCollection
        .add(tratamientoProgramado.toEntity().toDocument());
  }

  @override
  Future<void> deleteTratamientoProgramado(
      TratamientoProgramado tratamientoProgramado) {
    return tratamientosProgramadosCollection
        .document(tratamientoProgramado.uuid)
        .delete();
  }

  @override
  Stream<List<TratamientoProgramado>> tratamientosProgramados() {
    return tratamientosProgramadosCollection
        .snapshots().map((snapshot) {
          print(snapshot);
          return snapshot.documents.map((doc) => TratamientoProgramado.fromEntity(TratamientoProgramadoEntity.fromSnapshot(doc))).toList();
    });
  }

  @override
  Future<void> updateTratamientoProgramado(
      TratamientoProgramado tratamientoProgramado) {
    return tratamientosProgramadosCollection.document(tratamientoProgramado.uuid).updateData(tratamientoProgramado.toEntity().toDocument());
  }
}
